var unigen_hangul_8c =
[
    [ "PARAMS", "struct_p_a_r_a_m_s.html", null ],
    [ "get_hex_range", "unigen-hangul_8c.html#a97cb9bdd18abd681712b192f5729ad56", null ],
    [ "main", "unigen-hangul_8c.html#a0ddf1224851353fc92bfbff6f499fa97", null ],
    [ "parse_args", "unigen-hangul_8c.html#af21f77b695eb80e4d88265be6647978e", null ]
];